"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const argparse = __importStar(require("argparse"));
exports.argparse = argparse;
class ArgumentParserNode {
    constructor(options) {
        this.children = {};
        this._subparsers = undefined;
        if ('parent' in options) {
            this.name = options.name;
            this.parent = options.parent;
            this.root = options.parent.root;
            this.defaultOptions = this.parent.defaultOptions;
            this.subparserOptions = options.subparserOptions || this.parent.subparserOptions || {};
            this.parser = this.parent.subparsers.addParser(options.name, options.options || this.defaultOptions);
        }
        else {
            this.root = this;
            this.defaultOptions = options.defaults || {};
            this.subparserOptions = options.subparserOptions || {};
            this.parser = new argparse.ArgumentParser(options.options || this.defaultOptions);
        }
    }
    get(name, options) {
        if (!this.children.hasOwnProperty(name)) {
            this.children[name] = new this.constructor({ parent: this, name, options });
        }
        return this.children[name];
    }
    get subparsers() {
        if (!this._subparsers) {
            const options = Object.assign({}, this.subparserOptions);
            options.dest = `subparser_${this.level}`;
            this._subparsers = this.parser.addSubparsers(options);
            //(this.parser as any)._subparsers.defaultValue = null
        }
        return this._subparsers;
    }
    static getSelectedPathArray(options) {
        const parts = [];
        for (const entry of Object.entries(options)) {
            const [key, value] = entry;
            let result;
            if (result = this.subparserRegex.exec(key)) {
                const index = parseInt(result[1]);
                parts[index] = value;
            }
        }
        return parts;
    }
    getSelectedPathArray(options) {
        return ArgumentParserNode.getSelectedPathArray(options);
    }
    static getSelectedPath(options) {
        const parts = this.prototype.getSelectedPathArray(options);
        return parts.join('/');
    }
    getSelectedPath(options) {
        return ArgumentParserNode.getSelectedPath(options);
    }
    get level() {
        if (this.parent) {
            return this.parent.level + 1;
        }
        else
            return 0;
    }
    get pathArray() {
        if (this.parent) {
            const tmp = this.parent.pathArray;
            tmp.push(this.name);
            return tmp;
        }
        else
            return [];
    }
    get path() {
        return this.pathArray.join('/');
    }
}
ArgumentParserNode.subparserRegex = /^subparser_(.*)$/;
exports.ArgumentParserNode = ArgumentParserNode;
exports.ArgumentParserTree = ArgumentParserNode;
exports.default = exports.ArgumentParserTree;
//# sourceMappingURL=index.js.map